==> nextcloud-app-calendar-1%3A5.5.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/bn_BD.js <==
OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "শুভেচ্ছা!",
    "Calendar" : "দিনপঞ্জী",
    "Location:" : "অবস্থান:",
    "Today" : "আজ",
    "Day" : "দিবস",
    "Week" : "সপ্তাহ",
    "Month" : "মাস",
    "Copy link" : "লিঙ্ক কপি করো",
    "Edit" : "সম্পাদনা",
    "Delete" : "মুছে",
    "New calendar" : "নতুন দিনপঞ্জী",
    "Export" : "রপ্তানি",
    "Name" : "নাম",
    "Deleted" : "মুছে ফেলা",
    "Restore" : "ফিরিয়ে দাও",
    "Hidden" : "লুকনো",
    "Share link" : "লিংক ভাগাভাগি করেন",
    "can edit" : "সম্পাদনা করতে পারবেন",
    "Save" : "সংরক্ষণ",
    "Cancel" : "বাতিল",
    "Automatic" : "স্বয়ংক্রিয়",
    "Actions" : "পদক্ষেপসমূহ",
    "General" : "সাধারণ",
    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
    "Update" : "পরিবর্ধন",
    "Location" : "অবস্থান",
    "Description" : "বিবরণ",
    "to" : "প্রতি",
    "Add" : "যোগ করুন",
    "Monday" : "সোমবার",
    "Tuesday" : "মঙ্গলবার",
    "Wednesday" : "বুধবার",
    "Thursday" : "বৃহস্পতিবার",
    "Friday" : "শুক্রবার",
    "Saturday" : "শনিবার",
    "Sunday" : "রবিবার",
    "Your email address" : "আপনার ই-মেইল ঠিকানা",
    "Notification" : "নোটিফিকেশন ",
    "Email" : "ইমেইল",
    "seconds" : "সেকেন্ড",
    "minutes" : "মিনিটসমূহ",
    "hours" : "ঘন্টাসমূহ",
    "days" : "দিনগুলি",
    "weeks" : "সপ্তাহসমূহ",
    "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
    "Done" : "শেষ হলো",
    "Unknown" : "অজানা",
    "Attendees" : "অংশগ্রহণকারীবৃন্দ",
    "Repeat" : "পূনঃসংঘটন",
    "never" : "কখনোই নয়",
    "Yes" : "হ্যাঁ",
    "No" : "না",
    "Subscribe" : "গ্রাহক হোন",
    "Personal" : "ব্যক্তিগত",
    "Edit event" : "ইভেন্ট সম্পাদনা করুন",
    "Close" : "বন্ধ",
    "Daily" : "দৈনিক",
    "Weekly" : "সাপ্তাহিক",
    "second" : "সেকেন্ড",
    "Other" : "অন্যান্য"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-calendar-1%3A6.0.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/calendar/l10n/bn_BD.js <==
OC.L10N.register(
    "calendar",
    {
    "Cheers!" : "শুভেচ্ছা!",
    "Calendar" : "দিনপঞ্জী",
    "Location:" : "অবস্থান:",
    "Today" : "আজ",
    "Day" : "দিবস",
    "Week" : "সপ্তাহ",
    "Month" : "মাস",
    "Copy link" : "লিঙ্ক কপি করো",
    "Edit" : "সম্পাদনা",
    "Delete" : "মুছে",
    "New calendar" : "নতুন দিনপঞ্জী",
    "Export" : "রপ্তানি",
    "Name" : "নাম",
    "Deleted" : "মুছে ফেলা",
    "Restore" : "ফিরিয়ে দাও",
    "Share link" : "লিংক ভাগাভাগি করেন",
    "Save" : "সংরক্ষণ",
    "Cancel" : "বাতিল",
    "Automatic" : "স্বয়ংক্রিয়",
    "Actions" : "পদক্ষেপসমূহ",
    "General" : "সাধারণ",
    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
    "Update" : "পরিবর্ধন",
    "Location" : "অবস্থান",
    "Description" : "বিবরণ",
    "to" : "প্রতি",
    "Add" : "যোগ করুন",
    "Monday" : "সোমবার",
    "Tuesday" : "মঙ্গলবার",
    "Wednesday" : "বুধবার",
    "Thursday" : "বৃহস্পতিবার",
    "Friday" : "শুক্রবার",
    "Saturday" : "শনিবার",
    "Sunday" : "রবিবার",
    "Your email address" : "আপনার ই-মেইল ঠিকানা",
    "Notification" : "নোটিফিকেশন ",
    "Email" : "ইমেইল",
    "seconds" : "সেকেন্ড",
    "minutes" : "মিনিটসমূহ",
    "hours" : "ঘন্টাসমূহ",
    "days" : "দিনগুলি",
    "weeks" : "সপ্তাহসমূহ",
    "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
    "Done" : "শেষ হলো",
    "Unknown" : "অজানা",
    "Attendees" : "অংশগ্রহণকারীবৃন্দ",
    "Repeat" : "পূনঃসংঘটন",
    "never" : "কখনোই নয়",
    "Yes" : "হ্যাঁ",
    "No" : "না",
    "None" : "কোনটিই নয়",
    "Subscribe" : "গ্রাহক হোন",
    "Personal" : "ব্যক্তিগত",
    "Edit event" : "ইভেন্ট সম্পাদনা করুন",
    "Close" : "বন্ধ",
    "Daily" : "দৈনিক",
    "Weekly" : "সাপ্তাহিক",
    "second" : "সেকেন্ড",
    "Other" : "অন্যান্য",
    "Hidden" : "লুকনো",
    "can edit" : "সম্পাদনা করতে পারবেন"
},
"nplurals=2; plural=(n != 1);");
